Package: neuroim2
Type: Package
Title: Data Structures for Brain Imaging Data
Version: 0.13.0
LinkingTo: Rcpp, RcppArmadillo, RcppParallel
Author: Bradley R Buchsbaum [aut, cre, cph]
Authors@R: c(
    person(c("Bradley", "R"), "Buchsbaum", role = c("aut", "cre", "cph"), email = "brad.buchsbaum@gmail.com"))
Maintainer: Bradley R Buchsbaum <brad.buchsbaum@gmail.com>
Description: A collection of data structures and methods for handling volumetric
    brain imaging data, with a focus on functional magnetic resonance imaging (fMRI). Provides efficient
    representations for three-dimensional and four-dimensional neuroimaging data through sparse and dense array
    implementations, memory-mapped file access for large datasets, and
    spatial transformation capabilities. Implements methods for image resampling,
    spatial filtering, region of interest analysis, and connected component labeling. General introduction 
    to fMRI analysis can be found in Poldrack et al. (2024, "Handbook of functional MRI data analysis",
    <ISBN:9781108795760>). 
License: MIT + file LICENSE
Encoding: UTF-8
VignetteBuilder: knitr, rmarkdown
Depends: R (>= 4.3.0), Matrix
Collate: 'RcppExports.R' 'all_generic.R' 'all_class.R'
        'SparseNeuroVec-validity.R' 'affine_utils.R' 'afni_io.R'
        'array_like.R' 'axis.R' 'big_neurovec.R' 'binary_io.R' 'cgb.R'
        'cgb_nuisance.R' 'clustered_neurovec.R' 'clustervol.R'
        'common.R' 'conncomp.R' 'deoblique.R' 'downsample.R'
        'file_format.R' 'filebacked_neurovec.R' 'globals.R'
        'header_api.R' 'index_vol.R' 'mapped_neurovec.R' 'meta_info.R'
        'meta_info_api.R' 'neuro_obj.R' 'neurohypervec.R' 'neuroim.R'
        'neuroslice.R' 'neurospace.R' 'neurovec.R' 'neurovecseq.R'
        'neurovol.R' 'nifti_extensions.R' 'nifti_io.R' 'niml_io.R'
        'ops.R' 'orientation.R' 'palettes.R' 'plot-helpers.R'
        'plot-montage.R' 'plot-ortho.R' 'plot-overlay.R' 'read_image.R'
        'resample.R' 'resample_to.R' 'roi.R' 'searchlight.R'
        'show_helpers.R' 'simulate.R' 'space_utils.R'
        'sparse_neurovec.R' 'spat_filter.R' 'summary_methods.R'
        'theme.R' 'zzz.R'
RoxygenNote: 7.3.3
Imports: purrr, mmap, Rcpp, RcppParallel, RNifti, dbscan, stringr,
        methods, bigstatsr, RNiftyReg, future, future.apply, deflist,
        cli, ggplot2, magrittr, grid
Suggests: testthat, covr, knitr, pkgdown, roxygen2, rmarkdown,
        albersdown, Gmedian, R.utils, spelling, vdiffr, xml2
URL: https://github.com/bbuchsbaum/neuroim2,
        https://bbuchsbaum.github.io/neuroim2/
BugReports: https://github.com/bbuchsbaum/neuroim2/issues
Language: en-US
Config/Needs/website: bbuchsbaum/albersdown, albersdown
NeedsCompilation: yes
Packaged: 2026-04-16 15:55:54 UTC; bbuchsbaum
Repository: CRAN
Date/Publication: 2026-04-16 17:00:02 UTC
Built: R 4.5.2; x86_64-apple-darwin20; 2026-04-17 09:42:38 UTC; unix
Archs: neuroim2.so.dSYM
