# Generated by roxygen2: do not edit by hand

S3method(print,NeuroHeader)
S3method(print,summary.NeuroVec)
S3method(print,summary.NeuroVol)
export(ANT_POST)
export(BigNeuroVec)
export(BinaryReader)
export(BinaryWriter)
export(ClusteredNeuroVec)
export(ClusteredNeuroVol)
export(ColumnReader)
export(DenseNeuroVec)
export(DenseNeuroVol)
export(FileBackedNeuroVec)
export(INF_SUP)
export(IndexLookupVol)
export(Kernel)
export(LEFT_RIGHT)
export(LogicalNeuroVol)
export(MappedNeuroVec)
export(MappedNeuroVecSource)
export(MetaInfo)
export(NIFTIMetaInfo)
export(NeuroHyperVec)
export(NeuroSlice)
export(NeuroSpace)
export(NeuroVec)
export(NeuroVecSeq)
export(NeuroVol)
export(NeuroVolSource)
export(NiftiExtension)
export(NiftiExtensionCodes)
export(None)
export(NullAxis)
export(OrientationList2D)
export(OrientationList3D)
export(POST_ANT)
export(RIGHT_LEFT)
export(ROICoords)
export(ROIVec)
export(ROIVol)
export(SUP_INF)
export(SparseNeuroVec)
export(SparseNeuroVol)
export(TIME)
export(TimeAxis)
export(add_dim)
export(affine_to_axcodes)
export(affine_to_orientation)
export(annotate_orientation)
export(append_diag)
export(apply_affine)
export(apply_orientation)
export(as.array)
export(as.dense)
export(as.mask)
export(as.matrix)
export(as.sparse)
export(as_canonical)
export(as_mmap)
export(as_nifti_header)
export(axcodes)
export(axcodes_to_orientation)
export(axes)
export(bilateral_filter)
export(bilateral_filter_4d)
export(blobby_shape)
export(bootstrap_searchlight)
export(centroid)
export(centroids)
export(cgb_filter)
export(cgb_make_graph)
export(cgb_smooth)
export(cgb_smooth_loro)
export(cluster_searchlight_series)
export(clustered_searchlight)
export(concat)
export(conn_comp)
export(conn_comp_3D)
export(coord_to_grid)
export(coord_to_index)
export(coords)
export(createNIfTIHeader)
export(cube_shape)
export(cuboid_roi)
export(data_file)
export(data_file_matches)
export(data_reader)
export(deoblique)
export(dim_of)
export(dot_reduce)
export(downsample)
export(drop)
export(drop_dim)
export(ecode_name)
export(ellipsoid_shape)
export(embed_kernel)
export(extension)
export(extensions)
export(file_matches)
export(findAnatomy3D)
export(from_matvec)
export(gaussian_blur)
export(get_afni_attribute)
export(grid_to_coord)
export(grid_to_grid)
export(grid_to_index)
export(guided_filter)
export(has_extensions)
export(header)
export(header_file)
export(header_file_matches)
export(image)
export(index_to_coord)
export(index_to_grid)
export(indices)
export(inverse_trans)
export(laplace_enhance)
export(linear_access)
export(list_afni_attributes)
export(load_data)
export(lookup)
export(make_time_weights)
export(mapToColors)
export(map_values)
export(mapf)
export(mask)
export(matricized_access)
export(matrixToQuatern)
export(meta_info)
export(ndim)
export(num_clusters)
export(obliquity)
export(orientation_inverse_affine)
export(orientation_to_axcodes)
export(orientation_transform)
export(origin)
export(output_aligned_space)
export(parse_afni_extension)
export(parse_extension)
export(partition)
export(patch_set)
export(perm_mat)
export(plot)
export(plot_montage)
export(plot_ortho)
export(plot_overlay)
export(prepare_confounds)
export(quaternToMatrix)
export(random_searchlight)
export(read_columns)
export(read_elements)
export(read_header)
export(read_hyper_vec)
export(read_image)
export(read_meta_info)
export(read_vec)
export(read_vol)
export(read_vol_list)
export(reorient)
export(resample)
export(resample_to)
export(resampled_searchlight)
export(rescale_affine)
export(resolve_cmap)
export(scale)
export(scale_fill_neuro)
export(scale_series)
export(searchlight)
export(searchlight_coords)
export(series)
export(series_roi)
export(simulate_fmri)
export(slice)
export(slice2volume)
export(slice_to_volume_affine)
export(slices)
export(space)
export(spacing)
export(spherical_roi)
export(spherical_roi_set)
export(split_blocks)
export(split_clusters)
export(split_fill)
export(split_reduce)
export(split_scale)
export(square_roi)
export(strip_extension)
export(sub_clusters)
export(sub_vector)
export(temporal_access)
export(theme_neuro)
export(to_matvec)
export(trans)
export(values)
export(vec_from_vols)
export(vectors)
export(vols)
export(volume_labels)
export(vox2out_vox)
export(voxel_sizes)
export(voxels)
export(which_dim)
export(write_elements)
export(write_vec)
export(write_vol)
exportClasses(AFNIMetaInfo)
exportClasses(AbstractSparseNeuroVec)
exportClasses(ArrayLike3D)
exportClasses(ArrayLike4D)
exportClasses(ArrayLike5D)
exportClasses(AxisSet)
exportClasses(AxisSet1D)
exportClasses(AxisSet2D)
exportClasses(AxisSet3D)
exportClasses(AxisSet4D)
exportClasses(AxisSet5D)
exportClasses(BigNeuroVec)
exportClasses(BinaryReader)
exportClasses(BinaryWriter)
exportClasses(ClusteredNeuroVec)
exportClasses(ClusteredNeuroVol)
exportClasses(ColumnReader)
exportClasses(DenseNeuroVec)
exportClasses(DenseNeuroVol)
exportClasses(FileBackedNeuroVec)
exportClasses(FileFormat)
exportClasses(FileMetaInfo)
exportClasses(FileSource)
exportClasses(IndexLookupVol)
exportClasses(Kernel)
exportClasses(LogicalNeuroVol)
exportClasses(MappedNeuroVec)
exportClasses(MappedNeuroVecSource)
exportClasses(MetaInfo)
exportClasses(NIFTIMetaInfo)
exportClasses(NamedAxis)
exportClasses(NeuroBucket)
exportClasses(NeuroHyperVec)
exportClasses(NeuroObj)
exportClasses(NeuroSlice)
exportClasses(NeuroSpace)
exportClasses(NeuroVec)
exportClasses(NeuroVecSeq)
exportClasses(NeuroVecSource)
exportClasses(NeuroVol)
exportClasses(NiftiExtension)
exportClasses(NiftiExtensionList)
exportClasses(ROI)
exportClasses(ROICoords)
exportClasses(ROIVec)
exportClasses(ROIVecWindow)
exportClasses(ROIVol)
exportClasses(ROIVolWindow)
exportClasses(SparseNeuroVec)
exportClasses(SparseNeuroVecSource)
exportClasses(SparseNeuroVol)
exportClasses(numericOrMatrix)
exportMethods("!")
exportMethods("[")
exportMethods("[[")
exportMethods(Arith)
exportMethods(Compare)
exportMethods(Logic)
exportMethods(Summary)
exportMethods(add_dim)
exportMethods(as.array)
exportMethods(as.dense)
exportMethods(as.list)
exportMethods(as.logical)
exportMethods(as.mask)
exportMethods(as.matrix)
exportMethods(as.numeric)
exportMethods(as.sparse)
exportMethods(as.vector)
exportMethods(as_mmap)
exportMethods(axcodes)
exportMethods(axes)
exportMethods(bounds)
exportMethods(centroid)
exportMethods(centroids)
exportMethods(close)
exportMethods(concat)
exportMethods(conn_comp)
exportMethods(coord_to_grid)
exportMethods(coord_to_index)
exportMethods(coords)
exportMethods(data_file)
exportMethods(data_file_matches)
exportMethods(dim)
exportMethods(dim_of)
exportMethods(downsample)
exportMethods(drop)
exportMethods(drop_dim)
exportMethods(embed_kernel)
exportMethods(extension)
exportMethods(file_matches)
exportMethods(grid_to_coord)
exportMethods(grid_to_grid)
exportMethods(grid_to_index)
exportMethods(has_extensions)
exportMethods(header)
exportMethods(header_file)
exportMethods(header_file_matches)
exportMethods(index_to_coord)
exportMethods(index_to_grid)
exportMethods(indices)
exportMethods(inverse_trans)
exportMethods(labels)
exportMethods(length)
exportMethods(linear_access)
exportMethods(load_data)
exportMethods(lookup)
exportMethods(map_values)
exportMethods(mapf)
exportMethods(mask)
exportMethods(matricized_access)
exportMethods(mean)
exportMethods(meta_info)
exportMethods(ndim)
exportMethods(num_clusters)
exportMethods(origin)
exportMethods(patch_set)
exportMethods(perm_mat)
exportMethods(plot)
exportMethods(read_columns)
exportMethods(read_elements)
exportMethods(read_meta_info)
exportMethods(reorient)
exportMethods(resample)
exportMethods(scale_series)
exportMethods(series)
exportMethods(series_roi)
exportMethods(show)
exportMethods(slice)
exportMethods(slices)
exportMethods(space)
exportMethods(spacing)
exportMethods(split_blocks)
exportMethods(split_clusters)
exportMethods(split_fill)
exportMethods(split_reduce)
exportMethods(split_scale)
exportMethods(strip_extension)
exportMethods(sub_clusters)
exportMethods(sub_vector)
exportMethods(summary)
exportMethods(temporal_access)
exportMethods(trans)
exportMethods(values)
exportMethods(vectors)
exportMethods(vols)
exportMethods(volume_labels)
exportMethods(voxels)
exportMethods(which_dim)
exportMethods(write_elements)
exportMethods(write_vec)
exportMethods(write_vol)
import(Matrix)
import(RNifti)
import(methods)
importFrom(Matrix,sparseVector)
importFrom(Matrix,which)
importFrom(RNifti,asNifti)
importFrom(RNifti,niftiHeader)
importFrom(RNiftyReg,applyTransform)
importFrom(RNiftyReg,buildAffine)
importFrom(Rcpp,evalCpp)
importFrom(RcppParallel,RcppParallelLibs)
importFrom(bigstatsr,FBM)
importFrom(cli,format_inline)
importFrom(cli,rule)
importFrom(dbscan,frNN)
importFrom(dbscan,kNN)
importFrom(deflist,deflist)
importFrom(ggplot2,"%+replace%")
importFrom(ggplot2,aes)
importFrom(ggplot2,geom_raster)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,rel)
importFrom(ggplot2,scale_fill_gradientn)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,xlab)
importFrom(ggplot2,ylab)
importFrom(grDevices,col2rgb)
importFrom(grDevices,gray)
importFrom(grDevices,heat.colors)
importFrom(graphics,plot)
importFrom(grid,unit)
importFrom(magrittr,"%>%")
importFrom(methods,new)
importFrom(methods,setGeneric)
importFrom(mmap,char)
importFrom(mmap,int16)
importFrom(mmap,int32)
importFrom(mmap,int8)
importFrom(mmap,mmap)
importFrom(mmap,mmapFlags)
importFrom(mmap,munmap)
importFrom(mmap,real32)
importFrom(mmap,real64)
importFrom(mmap,uint8)
importFrom(purrr,flatten_dbl)
importFrom(purrr,map)
importFrom(purrr,map_dbl)
importFrom(purrr,map_int)
importFrom(purrr,map_lgl)
importFrom(purrr,reduce)
importFrom(stats,dist)
importFrom(stats,dnorm)
importFrom(stats,filter)
importFrom(stats,kmeans)
importFrom(stats,median)
importFrom(stats,rnorm)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stringr,str_split)
importFrom(stringr,str_sub)
importFrom(stringr,str_trim)
importFrom(utils,object.size)
importFrom(utils,str)
useDynLib(neuroim2, .registration = TRUE)
